@@ -9,7 +9,7 @@ use base qw(App::Pinto::Remote::Command);
 
 #-------------------------------------------------------------------------------
 
-our $VERSION = '0.028'; # VERSION
+our $VERSION = '0.030'; # VERSION
 
 #-------------------------------------------------------------------------------
 
@@ -34,7 +34,7 @@ sub usage_desc {
 
     my ($command) = $self->command_names();
 
-    return "%c --repos=URL $command [OPTIONS] ARCHIVE_FILE";
+    return "%c --root=URL $command [OPTIONS] ARCHIVE_FILE";
 }
 
 #-------------------------------------------------------------------------------
@@ -75,11 +75,11 @@ App::Pinto::Remote::Command::add - add a distribution to the remote repository
 
 =head1 VERSION
 
-version 0.028
+version 0.030
 
 =head1 SYNOPSIS
 
-  pinto-remote --repos=URL add [OPTIONS] ARCHIVE_FILE
+  pinto-remote --root=URL add [OPTIONS] ARCHIVE_FILE
 
 =head1 DESCRIPTION
 
